@@ -1,12 +1,12 @@
 """Better choices library for Django web framework."""
 
-from typing import Any, Iterator, Optional, Tuple, Union
+from typing import Any, Iterable, Iterator, Optional, Tuple, Union
 
 try:
     from django.utils.functional import Promise
 except ImportError:
     class Promise:
-        pass
+        ...
 
 from .version import __version__
 
@@ -26,83 +26,35 @@ class __ChoicesMetaclass(type):
         kwargs = (f"'{self.__name__}'", *(f'{k}={v.display!r}' for k, v in self.items()))
         return f"Choices({', '.join(kwargs)})"
 
+    def __or__(self, other: 'Choices') -> 'Choices':
+        return self.__operation(other, '|', (*self.items(), *other.items()))
+
+    def __and__(self, other: 'Choices') -> 'Choices':
+        return self.__operation(other, '&', ((k, v) for k, v in self.items() if other.has(k)))
+
+    def __sub__(self, other: 'Choices') -> 'Choices':
+        return self.__operation(other, '-', ((k, v) for k, v in self.items() if not other.has(k)))
+
+    def __xor__(self, other: 'Choices') -> 'Choices':
+        return self.__operation(other, '^', (
+            *((k, v) for k, v in self.items() if not other.has(k)),
+            *((k, v) for k, v in other.items() if not self.has(k))
+        ))
+
+    def __operation(self, other: 'Choices', op: str, items: Iterable[Tuple[str, 'Choices.Value']]) -> 'Choices':
+        return type(f'{self.__name__}{op}{other.__name__}', (Choices,), dict(items))
+
 
 class Choices(metaclass=__ChoicesMetaclass):
     """
     Choices class that should be overridden or initialised for constant class definition.
 
-    Example:
-        # init via class definition
-        class PAGE_STATUS(Choices):
-            CREATED = 'Created'
-            PENDING = Choices.Value('Pending', help_text='This set status to pending')
-            ON_HOLD = Choices.Value('On Hold', value='custom_on_hold')
-
-            VALID = Choices.Subset('CREATED', 'ON_HOLD')
-
-            # supports inner choices
-            class INTERNAL_STATUS(Choices):
-                REVIEW = 'On Review'
-
-        # init via inline definition
-        PAGE_STATUS = Choices('PAGE_STATUS', SUCCESS='Success', FAIL='Error')
-
-        # value accessors
-        value_created = PAGE_STATUS.CREATED
-        value_review = PAGE_STATUS.INTERNAL_STATUS.REVIEW
-        value_on_hold = getattr(PAGE_STATUS, 'ON_HOLD')
-
-        # values and value parameters
-        print( PAGE_STATUS.CREATED )                # 'created'
-        print( PAGE_STATUS.ON_HOLD )                # 'custom_on_hold'
-        print( PAGE_STATUS.PENDING.display )        # 'Pending'
-        print( PAGE_STATUS.PENDING.help_text )      # 'This set status to pending'
-
-        # values comparison
-        PAGE_STATUS.ON_HOLD == 'custom_on_hold'     # True
-        PAGE_STATUS.CREATED == PAGE_STATUS.CREATED  # True
-
-        # search in choices
-        'created' in PAGE_STATUS                    # True
-        'custom_on_hold' in PAGE_STATUS             # True
-        'on_hold' in PAGE_STATUS                    # False
-        value = PAGE_STATUS['custom_on_hold']       # Choices.Value
-        key, value = PAGE_STATUS.find('created')    # ('CREATED', Choices.Value)
-
-        # search in subsets
-        'custom_on_hold' in PAGE_STATUS.VALID       # True
-        PAGE_STATUS.CREATED in PAGE_STATUS.VALID    # True
-
-        # extract subset
-        PAGE_STATUS.extract('CREATED', 'ON_HOLD')   # ~= PAGE_STATUS.VALID
-        PAGE_STATUS.VALID.extract('ON_HOLD')        # Choices('PAGE_STATUS.VALID.Subset', ON_HOLD)
-
-        # choices iteration
-        for value, display in PAGE_STATUS:
-            print( value, display )
-        for key, value in PAGE_STATUS.items():
-            print( key, value, value.display )
-        for key in PAGE_STATUS.keys():
-            print( key )
-        for value in PAGE_STATUS.values():
-            print( value, value.display, value.__choice_entry__ )
-        for display in PAGE_STATUS.displays():
-            print( display )
-        for display in PAGE_STATUS.SUBSET.displays():
-            print( display )
-
-        # Django model fields
-        class Page(models.Model):
-            status = models.CharField(choices=PAGE_STATUS, default=PAGE_STATUS.CREATED)
-
-        # saving choices values on models
-        page = Page.objects.get(pk=1)
-        page.status = PAGE_STATUS.PENDING
-        page.save()
+    Examples:
+        https://pypi.org/project/django-better-choices/
     """
 
     class Value(str):
-        """And immutable string class that contains choices value configuration."""
+        """An immutable string class that contains choices value configuration."""
 
         capitalize = casefold = center = count = encode = endswith = expandtabs = find = format = format_map = \
             index = isalnum = isalpha = isascii = isdecimal = isdigit = isidentifier = islower = isnumeric = \
@@ -114,7 +66,7 @@ class Choices(metaclass=__ChoicesMetaclass):
             """
             Custom value class definition to support extended functionality.
 
-            Args:
+            Arguments:
                 display (Union[str, Promise]): Text used to represent the value.
                 value (str): Custom value of the value (if empty, choices key lowercase will be used).
                 params: Additional value parameters.
@@ -128,10 +80,14 @@ class Choices(metaclass=__ChoicesMetaclass):
             try:
                 return self.__params[name]
             except KeyError:
+                if hasattr(str, name):
+                    def wrapper(*args, **kwargs):  # native str method
+                        return getattr(str, name)(self, *args, **kwargs)
+                    return wrapper
                 raise AttributeError(f"'Value' object has no attribute '{name}'") from None
 
         def __clone__(self, value: str) -> 'Choices.Value':
-            return self.__class__(self.__display, value=value, **self.__params)
+            return Choices.Value(self.__display, value=value, **self.__params)
 
         @property
         def __choice_entry__(self) -> Tuple[str, str]:
@@ -147,9 +103,6 @@ class Choices(metaclass=__ChoicesMetaclass):
         def __new__(cls, *keys: str):
             return super().__new__(cls, dict.fromkeys(keys).keys())
 
-        def __getattr__(self, _: str) -> Any:
-            """Make IDE happy."""
-
     def __new__(cls, name: Optional[str] = None, **values: Union['Value', str, Promise]):
         if cls is not Choices:
             return tuple(cls)
@@ -188,11 +141,10 @@ class Choices(metaclass=__ChoicesMetaclass):
     def __class_getitem__(cls, value: str) -> 'Value':
         return cls.__values[cls.__keys[value]]
 
-    def __getattr__(self, _: str) -> Any:
-        """Make IDE happy for inline definition."""
-
-    def __iter__(self) -> 'Value':
-        """Make IDE happy for inline definition."""
+    @classmethod
+    def has(cls, key: str) -> bool:
+        """Check if key exists in the choices class."""
+        return key in cls.__values
 
     @classmethod
     def items(cls) -> Tuple[Tuple[str, 'Value'], ...]:
@@ -224,6 +176,6 @@ class Choices(metaclass=__ChoicesMetaclass):
         return key, cls.__values[key]
 
     @classmethod
-    def extract(cls, *keys: str, name='Subset') -> 'Choices':
+    def extract(cls, *keys: str, name: str = 'Subset') -> 'Choices':
         """Dynamically extract a subset of values from the choices class."""
         return type(f'{cls.__name__}.{name}', (cls,), {k: cls.__values[k] for k in keys})
